import pytest
from fileformats.vendor.fsl.medimage import (
    Con,
)


@pytest.mark.xfail(reason="generate_sample_data not implemented")
def test_generate_sample_con_data():
    assert isinstance(Con.sample(), Con)



from ._version import __version__  # noqa: F401
from pathlib import Path
import typing as ty
from random import Random
from fileformats.core import FileSet, SampleFileGenerator
from fileformats.vendor.fsl.medimage import (
    Con,
)


@FileSet.generate_sample_data.register
def gen_sample_con_data(con: Con, generator: SampleFileGenerator) -> ty.Iterable[Path]:
    raise NotImplementedError
